@@ -4,7 +4,7 @@ use 5.008;
 use warnings;
 use strict;
 use Carp;
-use version; our $VERSION = qv('0.0.20');
+use version; our $VERSION = qv('0.0.21');
 
 my %cache;
 my $tmp;            # used for hold temporary data
@@ -190,7 +190,7 @@ sub _seek {
 
 sub _str {
     my $self = shift;
-    my $str;
+    my $str  = '';
 
     read $self->{fh}, $tmp, 1;
     while ( ord $tmp > 0 ) {
@@ -319,7 +319,7 @@ sunnavy  C<< <sunnavy@gmail.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2006-2011, sunnavy C<< <sunnavy@gmail.com> >>.
+Copyright (c) 2006-2020, sunnavy C<< <sunnavy@gmail.com> >>.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
